ClientMessage

Enum ClientMessage 

pub enum ClientMessage {
Show 13 variants Hello { extra: BoltDict, }, Logon { auth: BoltDict, }, Logoff, Goodbye, Reset, Run { query: String, parameters: BoltDict, extra: BoltDict, }, Pull { extra: BoltDict, }, Discard { extra: BoltDict, }, Begin { extra: BoltDict, }, Commit, Rollback, Route { routing: BoltDict, bookmarks: Vec<String>, extra: BoltDict, }, Telemetry { api: i64, },
}
A message sent from the client to the server.

Variants



Hello

Initialize connection. Sent once after handshake.

Fields

extra: BoltDict


Logon

Authenticate after HELLO (Bolt 5.1+).

Fields



Logoff

De-authenticate (Bolt 5.1+).



Goodbye

Gracefully close the connection.



Reset

Reset the connection to a clean state, aborting any pending work.



Run

Execute a query (auto-commit or within a transaction).

Fields

query: String
parameters: BoltDict
extra: BoltDict


Pull

Pull results from the last RUN.

Fields

extra: BoltDict


Discard

Discard results from the last RUN.

Fields

extra: BoltDict


Begin

Begin an explicit transaction.

Fields

extra: BoltDict


Commit

Commit the current explicit transaction.



Rollback

Roll back the current explicit transaction.



Route

Request routing table for cluster-aware drivers (Bolt 5.2+).

Fields

routing: BoltDict
bookmarks: Vec<String>
extra: BoltDict


Telemetry

Client telemetry data (Bolt 5.4+). Server may safely ignore.

Fields

api: i64

Implementations

Source

impl ClientMessage

pub fn pull_all() -> Self

Creates a PULL message requesting all remaining records.

pub fn pull_n(n: i64) -> Self

Creates a PULL message requesting n records.

pub fn discard_all() -> Self

Creates a DISCARD message discarding all remaining records.